<?php

namespace Assetdocs\Student\Policies;

use Litepie\User\Contracts\UserPolicy;
use Assetdocs\Student\Models\Student;

class StudentPolicy
{

    /**
     * Determine if the given user can view the student.
     *
     * @param UserPolicy $user
     * @param Student $student
     *
     * @return bool
     */
    public function view(UserPolicy $user, Student $student)
    {
        if ($user->canDo('student.student.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $student->user_id;
    }

    /**
     * Determine if the given user can create a student.
     *
     * @param UserPolicy $user
     * @param Student $student
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('student.student.create');
    }

    /**
     * Determine if the given user can update the given student.
     *
     * @param UserPolicy $user
     * @param Student $student
     *
     * @return bool
     */
    public function update(UserPolicy $user, Student $student)
    {
        if ($user->canDo('student.student.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $student->user_id;
    }

    /**
     * Determine if the given user can delete the given student.
     *
     * @param UserPolicy $user
     * @param Student $student
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Student $student)
    {
        if ($user->canDo('student.student.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $student->user_id;
    }

    /**
     * Determine if the given user can verify the given student.
     *
     * @param UserPolicy $user
     * @param Student $student
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Student $student)
    {
        if ($user->canDo('student.student.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('student.student.verify') 
        && $user->is('manager')
        && $student->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given student.
     *
     * @param UserPolicy $user
     * @param Student $student
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Student $student)
    {
        if ($user->canDo('student.student.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
